@@ -7,5 +7,5 @@ from dbt.include import flink
 
 
 Plugin = AdapterPlugin(
-    adapter=FlinkAdapter, credentials=FlinkCredentials, include_path=flink.PACKAGE_PATH
+    adapter=FlinkAdapter, credentials=FlinkCredentials, include_path=flink.PACKAGE_PATH  # type: ignore
 )
