@@ -19,13 +19,15 @@
 {%- endmacro %}
 
 {% macro flink__create_table_as(temporary, relation, sql) -%}
+  {% set type = config.get('type', None) %}
   {%- set sql_header = config.get('sql_header', none) -%}
   {% set connector_properties = config.get('connector_properties') %}
 
   {{ sql_header if sql_header is not none }}
 
   create {% if temporary: -%}temporary{%- endif %} table
-    {{ relation.include(database=(not temporary), schema=(not temporary)) }}
+    {{ this.render() }}
+    {% if type %}/** mode('{{type}}')*/{% endif %}
   with (
     {% for property_name in connector_properties %} '{{ property_name }}' = '{{ connector_properties[property_name] }}'{% if not loop.last %},{% endif %}
     {% endfor %}
